@@ -4,8 +4,7 @@
 #include <string.h>
 #include <time.h>
 
-#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include "weather-priv.h"
+#include "gweather-private.h"
 
 int
 main (int argc, char **argv)
