@@ -25,8 +25,7 @@
 #include <sys/types.h>
 #include <regex.h>
 
-#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include "weather-priv.h"
+#include "gweather-private.h"
 
 enum {
     TIME_RE,
